@@ -54,6 +54,10 @@ import Data.String (IsString(..))
 import Control.Monad
 #endif
 
+#if MIN_VERSION_xml_conduit(1,10,0)
+import Text.XML.Stream.Render.Internal (rsPretty)
+#endif
+
 -- | Node container to be rendered as children nodes.
 type XML = Writer (DL.DList Node) ()
 
